function filter_params = gen_filters()
% Function that sets the parameters of several filters. Note that 
% parameters for all three implementations (KF, UKF and SMC) are generated
% even though in some simulations only specific variants are used.
%
% Contact: augustin.saucan@mail.mcgill.ca

%% MS-MeMBer Gaussian mixture (Kalman filter) filter parameters
filter_params.ms_member_kf.title              = 'MS MeMBer KF';
filter_params.ms_member_kf.comp_max           = 100;         % maximum number of components
filter_params.ms_member_kf.nb_comp_tg         = 4;           % nb of components per target, used for pruning
filter_params.ms_member_kf.comp_threshold     = 0.05;        % pruning threshold for components/hypotheses
filter_params.ms_member_kf.W_max              = 4;           % maximum number of subsets
filter_params.ms_member_kf.P_max              = 4;           % maximum number of partitions
filter_params.ms_member_kf.run_flag           = 'silence';   %'disp' or 'silence' for on the fly output
%% MS-MeMBer Unscented Kalman filter parameters for non-linear state models
filter_params.ms_member_ukf.title              = 'MS MeMBer UKF';
filter_params.ms_member_ukf.comp_max           = 100;         % maximum number of components
filter_params.ms_member_ukf.nb_comp_tg         = 4;           % nb of components per target, used for pruning  
filter_params.ms_member_ukf.comp_threshold     = 1e-10;       % pruning threshold for components/hypotheses
filter_params.ms_member_ukf.W_max              = 4;           % maximum number of subsets 
filter_params.ms_member_ukf.P_max              = 4;           % maximum number of partitions 
filter_params.ms_member_ukf.ukf.lambda         = 2;           % ukf param


filter_params.ms_member_ukf.run_flag           = 'silence';   %'disp' or 'silence' for on the fly output
%% MS-MeMBer SMC parameters for non-linear state models
filter_params.ms_member_smc.title              = 'MS Multi-Bernoulli SMC';
filter_params.ms_member_smc.comp_max           = 100;         % maximum number of components
filter_params.ms_member_smc.nb_comp_tg         = 4;           % nb of components per target, used for pruning  
filter_params.ms_member_smc.comp_threshold     = 1e-10;       % pruning threshold for components/hypotheses
filter_params.ms_member_smc.nb_part            = 700;         % nb of particles per target
filter_params.ms_member_smc.nb_eff_part        = round( 2/3 * filter_params.ms_member_smc.nb_part );                    %threshold on effective number of particles before resampling
filter_params.ms_member_smc.W_max              = 4;           % maximum number of subsets 
filter_params.ms_member_smc.P_max              = 4;           % maximum number of partitions 
filter_params.ms_member_smc.run_flag           = 'silence';   %'disp' or 'silence' for on the fly output


%% MS-CPHD Gaussian mixture (Kalman filter) filter parameters
filter_params.ms_cphd_kf.title              = 'MS CPHD KF';
filter_params.ms_cphd_kf.comp_max           = 100;         % maximum number of components
filter_params.ms_cphd_kf.nb_comp_tg         = 4;           % nb of components per target, used for pruning  
filter_params.ms_cphd_kf.comp_threshold     = 1e-3;        % pruning threshold for components/hypotheses
filter_params.ms_cphd_kf.merge_threshold    = 2;           % mergng threshold for components/hypotheses
filter_params.ms_cphd_kf.W_max              = 4;           % maximum number of subsets 
filter_params.ms_cphd_kf.P_max              = 4;           % maximum number of partitions 
filter_params.ms_cphd_kf.max_card           = 20;          % maximum number of targets 
filter_params.ms_cphd_kf.run_flag           = 'silence';   %'disp' or 'silence' for on the fly output
%% MS-TCPHD Unscented Kalman filter parameters for non-linear state models
filter_params.ms_cphd_ukf.title              = 'MS CPHD UKF';
filter_params.ms_cphd_ukf.comp_max           = 100;         % maximum number of components
filter_params.ms_cphd_ukf.nb_comp_tg         = 4;           % nb of components per target, used for pruning  
filter_params.ms_cphd_ukf.comp_threshold     = 1e-10;       % pruning threshold for components/hypotheses
filter_params.ms_cphd_ukf.merge_threshold    = 5;           % mergng threshold for components/hypotheses
filter_params.ms_cphd_ukf.W_max              = 4;           % maximum number of subsets 
filter_params.ms_cphd_ukf.P_max              = 4;           % maximum number of partitions 
filter_params.ms_cphd_ukf.max_card           = 20;          % maximum number of targets 
filter_params.ms_cphd_ukf.run_flag           = 'silence';   %'disp' or 'silence' for on the fly output
filter_params.ms_cphd_ukf.ukf.lambda         = 2;           % ukf param

%% MS-CPHD SMC parameters for non-linear state models
filter_params.ms_cphd_smc.title              = 'MS CPHD SMC';
filter_params.ms_cphd_smc.comp_max           = 100;         % maximum number of components
filter_params.ms_cphd_smc.nb_comp_tg         = 4;           % nb of components per target, used for pruning  
filter_params.ms_cphd_smc.comp_threshold     = 1e-10;       % pruning threshold for components/hypotheses
filter_params.ms_cphd_smc.merge_threshold    = 5;           % mergng threshold for components/hypotheses
filter_params.ms_cphd_smc.nb_part            = 700;         % nb of particles per target
filter_params.ms_cphd_smc.nb_eff_part        = round( 2/3 * filter_params.ms_cphd_smc.nb_part );                    %threshold on effective number of particles before resampling
filter_params.ms_cphd_smc.W_max              = 4;           % maximum number of subsets 
filter_params.ms_cphd_smc.P_max              = 4;           % maximum number of partitions 
filter_params.ms_cphd_smc.max_card           = 20;          % maximum number of targets 
filter_params.ms_cphd_smc.run_flag           = 'silence';   %'disp' or 'silence' for on the fly output


%% MS-TCPHD Gaussian mixture (Kalman filter) filter parameters
filter_params.ms_tcphd_kf.title              = 'MS TCPHD KF';
filter_params.ms_tcphd_kf.comp_max           = 100;         % maximum number of components
filter_params.ms_tcphd_kf.nb_comp_tg         = 4;           % nb of components per target, used for pruning  
filter_params.ms_tcphd_kf.comp_threshold     = 1e-3;        % pruning threshold for components/hypotheses
filter_params.ms_tcphd_kf.merge_threshold    = 2;           % mergng threshold for components/hypotheses
filter_params.ms_tcphd_kf.W_max              = 4;           % maximum number of subsets 
filter_params.ms_tcphd_kf.P_max              = 4;           % maximum number of partitions 
filter_params.ms_tcphd_kf.max_card           = 20;          % maximum number of targets 
filter_params.ms_tcphd_kf.run_flag           = 'silence';   %'disp' or 'silence' for on the fly output
%% MS-TCPHD Unscented Kalman filter parameters for non-linear state models
filter_params.ms_tcphd_ukf.title              = 'MS TCPHD UKF';
filter_params.ms_tcphd_ukf.comp_max           = 100;         % maximum number of components
filter_params.ms_tcphd_ukf.nb_comp_tg         = 4;           % nb of components per target, used for pruning  
filter_params.ms_tcphd_ukf.comp_threshold     = 1e-10;       % pruning threshold for components/hypotheses
filter_params.ms_tcphd_ukf.merge_threshold    = 5;           % mergng threshold for components/hypotheses
filter_params.ms_tcphd_ukf.W_max              = 4;           % maximum number of subsets 
filter_params.ms_tcphd_ukf.P_max              = 4;           % maximum number of partitions 
filter_params.ms_tcphd_ukf.max_card           = 20;          % maximum number of targets 
filter_params.ms_tcphd_ukf.run_flag           = 'silence';   %'disp' or 'silence' for on the fly output
filter_params.ms_tcphd_ukf.ukf.lambda         = 2;           % ukf param

%% MS-TCPHD SMC parameters for non-linear state models
filter_params.ms_tcphd_smc.title              = 'MS TCPHD SMC';
filter_params.ms_tcphd_smc.comp_max           = 100;         % maximum number of components
filter_params.ms_tcphd_smc.nb_comp_tg         = 4;           % nb of components per target, used for pruning  
filter_params.ms_tcphd_smc.comp_threshold     = 1e-10;       % pruning threshold for components/hypotheses
filter_params.ms_tcphd_smc.merge_threshold    = 5;           % mergng threshold for components/hypotheses
filter_params.ms_tcphd_smc.nb_part            = 700;         % nb of particles per target
filter_params.ms_tcphd_smc.nb_eff_part        = round( 2/3 * filter_params.ms_tcphd_smc.nb_part );                    %threshold on effective number of particles before resampling
filter_params.ms_tcphd_smc.W_max              = 4;           % maximum number of subsets 
filter_params.ms_tcphd_smc.P_max              = 4;           % maximum number of partitions 
filter_params.ms_tcphd_smc.max_card           = 20;          % maximum number of targets 
filter_params.ms_tcphd_smc.run_flag           = 'silence';   %'disp' or 'silence' for on the fly output

%% IC-CBMeMBer Kalman filter
filter_params.ic_cbmember_kf.title                 = 'IC-CBMeMBer KF';
filter_params.ic_cbmember_kf.comp_max              = 100;         % maximum number of components
filter_params.ic_cbmember_kf.nb_comp_tg            = 10;          % nb of components per target, used for pruning  
filter_params.ic_cbmember_kf.comp_threshold        = 1e-3;       % pruning threshold for components/hypotheses
filter_params.ic_cbmember_kf.run_flag              = 'silence';   %'disp' or 'silence' for on the fly output
filter_params.ic_cbmember_kf.mix.merge_threshold   = 4;           % merging threshold for Gaussians in each Bernoulli component 
filter_params.ic_cbmember_kf.mix.elim_threshold    = 1e-5;        % pruning threshold for Gaussians in each Bernoulli component 
filter_params.ic_cbmember_kf.mix.L_max             = 1;           % limit on number of Gaussians in each Bernoulli component 
%% IC-CBMeMBer UKF filter
filter_params.ic_cbmember_ukf.title                 = 'IC-CBMeMBer UKF';
filter_params.ic_cbmember_ukf.comp_max              = 100;         % maximum number of components
filter_params.ic_cbmember_ukf.nb_comp_tg            = 20;          % nb of components per target, used for pruning  
filter_params.ic_cbmember_ukf.comp_threshold        = 1e-10;       % pruning threshold for components/hypotheses
filter_params.ic_cbmember_ukf.run_flag              = 'silence';   %'disp' or 'silence' for on the fly output
filter_params.ic_cbmember_ukf.ukf.lambda            = 2;           % ukf param

filter_params.ic_cbmember_ukf.mix.merge_threshold   = 4;           % merging threshold for Gaussians in each Bernoulli component 
filter_params.ic_cbmember_ukf.mix.elim_threshold    = 1e-5;        % pruning threshold for Gaussians in each Bernoulli component 
filter_params.ic_cbmember_ukf.mix.L_max             = 1;           % limit on number of Gaussians in each Bernoulli component 
%% IC-CBMeMBer SMC filter
filter_params.ic_cbmember_smc.title              = 'IC-CBMeMBer SMC';
filter_params.ic_cbmember_smc.comp_max           = 100;         % maximum number of components
filter_params.ic_cbmember_smc.nb_comp_tg         = 20;          % nb of components per target, used for pruning  
filter_params.ic_cbmember_smc.comp_threshold     = 1e-10;       % pruning threshold for components/hypotheses
filter_params.ic_cbmember_smc.nb_part            = 700;         % nb of particles per target
filter_params.ic_cbmember_smc.run_flag           = 'silence';   %'disp' or 'silence' for on the fly output


end