function meas = gen_meas_bearing_doppler(model, truth, varargin)
% meas = gen_meas_linGauss(model, truth, varargin)
% INPUT:
%      model - struc that contains kinematic and obs. model params. 
%      truth - struc that cointains groungtruth tracks
%      varargin{1} - (optional) specify seed for MATLAB's rng (usefull for debug)
% OUTPUT: 
%      meas - struct that contains measurements
%
% Function designed to generate measurements for a non-linear observation
% model.
%
% Contact: augustin.saucan@mail.mcgill.ca

%variables
meas.K = truth.K;
meas.Z = cell(truth.K, 1);

% set up the Mersenne Twister generator for the repeatability of the simulations
if (~isempty(varargin)) && (~isempty(varargin{1}))
    stream = RandStream('mt19937ar', 'seed', varargin{1});
    RandStream.setGlobalStream(stream);
end

% generate measurements
for k = 1:truth.K   
    
    X = truth.X{k};
    Z = cell(1,model.obs.nb_sensors);
    nb_targ = size(X,2);
    
    for s = 1:model.obs.nb_sensors        
        % Generate target measurements
        if ~isempty(X)
            Zl = model.obs.gen_sen_obs(s, X, []);
            Zl = Zl + sqrtm(model.obs.R) * randn(size(Zl));

            idx = find(rand(1,nb_targ) <= model.obs.pD(s));
            Z{s} = [];
            if ~isempty(idx)
                Z{s} = Zl(:,idx);
            end
        end
        
        % Generate clutter for sensor s
        N_c       = poissrnd(model.obs.lambda_c);                                                                  % number of clutter points
        C         = repmat(model.obs.range_c(:,1),[1 N_c])+ diag(model.obs.range_c*[ -1; 1 ])*rand(model.obs.z_dim, N_c);  % clutter generation
        
        % append clutter measurements to target measurements
        Zord = [ Z{s} C ];
        % Radomize order of target-originated and clutter measuremnts
        nb_meas = size(Zord,2); 
        if nb_meas == 0
            Z{s} = [];
        else 
            Zrand = Zord(:, randperm(nb_meas));
            Z{s}  = Zrand;
        end
    end % for s 
    meas.Z{k} = Z;
end % for k
    
   
end
    
