function [ hfig ] = box_plot_run_time_linGauss( MC_results, truth, nb_sensors_param, MC )
% [ hfig ] = box_plot_time_averaged_OSPA_linGauss( MC_results, nb_sensors_param, pD_param, MC )
%   The function plots the results for 4 methods in a condensed bob-plot format. 
%   Function creats a box-plot of time-averaged OSPA values for all MC runs
%   and all parameter values of nb_sensors.   


nb_methods = 4;


 model = MC_results(1).model;

X = []; Y = []; Z = []; U = []; ACTid = [];

for s_idx = 1:length(nb_sensors_param)
    U   = [U; MC_results(s_idx).ic_cbmember.all_time/truth.K];
    X   = [X; MC_results(s_idx).ms_cphd.all_time/truth.K];
    Y   = [Y; MC_results(s_idx).ms_tcphd.all_time/truth.K];
    Z   = [Z; MC_results(s_idx).ms_member.all_time/truth.K];
    
    ACTid =  [ACTid; s_idx*ones(MC,1)];
end

my_labels = {' ', ' ', 's=3',' ','', ' ', ' ', 's=5','','',' ', ' ', 's=7',' ','','','', 's=9',' ','','','','s=11',' '};


xylabel = repmat('xyzu', length(nb_sensors_param)*MC,1);
hfig = figure;
h_box = boxplot([U; X; Y; Z], {repmat(ACTid,nb_methods,1),  xylabel(:)} ,'factorgap',  5.2, 'Widths', 0.9,  'FactorSeparator',[1]);
box on
set(gca,'ygrid','on') 

set(gca,'xtick',1:25, 'xticklabel', my_labels) 
a = get(gca,'XTickLabel');
set(gca,'xTickLabel', a,'fontsize', 35, 'fontweight', 'bold')

color = ['g', 'c', 'y', 'm', 'g', 'c', 'y', 'm', 'g', 'c', 'y', 'm', 'g', 'c', 'y', 'm', 'g', 'c', 'y', 'm', 'g', 'c', 'y'];

h = findobj(gca,'Tag','Box');
for j=1:length(h)
   patch(get(h(j),'XData'),get(h(j),'YData'),color(j),'FaceAlpha',.5);
end

c = get(gca, 'Children');

legend(c(1:4), 'IC-CBMeMBer', 'MS-CPHD', 'MS-TCPHD','MS-MeMBer' );
ylabel('Computational time')
%ylim([2.5 17])

for ii=1:size(h_box,2) %  for each box in the box plot 
     set(h_box(1:4,ii),'linewidth',2);  % 1:4 are the wiskers
    
     if mod(ii,nb_methods) == 1
         set(h_box(5,ii),'linewidth',2, 'color','m');  % 5 is the box
     elseif mod(ii,nb_methods) == 2     
         set(h_box(5,ii),'linewidth',2, 'color','y');  % 5 is the box
     elseif mod(ii,nb_methods) == 3
         set(h_box(5,ii),'linewidth',2, 'color','c');  % 5 is the box
     else
         set(h_box(5,ii),'linewidth',2, 'color','g');  % 5 is the box
     end
     
     set(h_box(6,ii),'linewidth', 5, 'color','k');  % 6 is the median       
end

set(findall(hfig,'type','text'),'fontSize',25, 'fontName', 'Helvetica','fontWeight','bold')
set(gca,'LineWidth',2,'FontSize',40);

title_str = ['Comp. time {p_D} = ', num2str(model.obs.pD(1)) , ' and no. sensors'];
title(title_str,  'Interpreter', 'TeX ', 'fontsize',28, 'fontName', 'Helvetica','fontWeight', 'Bold')


end % function end
