function [ hfig ] = box_plot_time_averaged_OSPA_linGauss_3methods( MC_results, nb_sensors_param, MC )
% [ hfig ] = box_plot_time_averaged_OSPA_linGauss( MC_results, nb_sensors_param, pD_param, MC )
%   The function plots the results for 4 methods in a condensed bob-plot format. 
%   Function creats a box-plot of time-averaged OSPA values for all MC runs
%   and all parameter values of nb_sensors.   

nb_methods = 3;

 model = MC_results(1).model;

X = []; Y = []; Z = []; U = []; ACTid = [];

for s_idx = 1:length(nb_sensors_param)
    X   = [X; mean(MC_results(s_idx).ms_cphd.ospa,2)];
    Y   = [Y; mean(MC_results(s_idx).ms_tcphd.ospa,2)];
    Z   = [Z; mean(MC_results(s_idx).ms_member.ospa,2)];
    
    ACTid =  [ACTid; s_idx*ones(MC,1)];
end

my_labels = {' ', 's=3',' ','', ' ', 's=5','','',' ', 's=7',' ','',' ', 's=9',' ','',' ', 's=11',' '};

xylabel = repmat('xyz',length(nb_sensors_param)*MC,1);
hfig = figure;
h_box = boxplot([X; Y; Z], {repmat(ACTid,nb_methods,1),  xylabel(:)} ,'factorgap',7.1, 'Widths', 0.9,  'FactorSeparator',[1]);
box on
set(gca,'ygrid','on') 

set(gca,'xtick',1:20, 'xticklabel', my_labels) 
a = get(gca,'XTickLabel');
set(gca,'xTickLabel', a,'fontsize', 35, 'fontweight', 'bold')

color = ['g', 'c', 'y',  'g', 'c', 'y', 'g', 'c', 'y', 'g', 'c', 'y', 'g', 'c', 'y'];
h = findobj(gca,'Tag','Box');
for j=1:length(h)
   patch(get(h(j),'XData'),get(h(j),'YData'),color(j),'FaceAlpha',.5);
end

c = get(gca, 'Children');

legend(c(1:3), 'MS-CPHD', 'MS-TCPHD','MS-MeMBer' );

for i=1:size(h_box,2) %  for each box in the box plot 
     set(h_box(1:4,i),'linewidth',2);  % 1:4 are the wiskers
    
     if mod(i,3) == 1
         set(h_box(5,i),'linewidth',2, 'color','y');  % 5 is the box
     elseif mod(i,3) == 2
         set(h_box(5,i),'linewidth',2, 'color','c');  % 5 is the box
     else
         set(h_box(5,i),'linewidth',2, 'color','g');  % 5 is the box
     end
     
     set(h_box(6,i),'linewidth', 5, 'color','k');  % 6 is the median  
     
end

set(findall(hfig,'type','text'),'fontSize',25, 'fontName', 'Helvetica','fontWeight','bold')
set(gca,'LineWidth',2,'FontSize',40);

title_str = ['Time-average OSPA $p_D$ = ', num2str(model.obs.pD(1)) , ' and no. sensors'];
title(title_str,  'Interpreter', 'LaTeX ', 'fontsize',40, 'fontName', 'Helvetica','fontWeight', 'Bold')

ylabel('Average OSPA error', 'Interpreter', 'LaTeX ', 'fontsize', 52, 'fontName', 'Helvetica','fontWeight', 'Bold')


end % function end
