function [ hfig ] = box_plot_time_averaged_OSPA_pD_bearing_doppler( MC_results, pD_var, MC )
% [ hfig ] = box_plot_time_averaged_OSPA_bearing_doppler( MC_results, nb_sensors_param, pD_param, MC )
%   The function plots the results for 6 methods in a condensed bob-plot format. 
%   Function creats a box-plot of time-averaged OSPA values for all MC runs
%   and all parameter values of nb_sensors.   


nb_methods = 6;
nb_pD = length(pD_var);

Xukf = []; Xsmc = []; Yukf  = []; Ysmc = []; Zukf = []; Zsmc = []; ACTid =  [];

for i = 1:nb_pD
    Xukf   = [Xukf; mean(MC_results(i).ms_cphd_ukf.ospa(1:MC,:),2)];
    Xsmc   = [Xsmc; mean(MC_results(i).ms_cphd_smc.ospa(1:MC,:),2)];
    Yukf   = [Yukf; mean(MC_results(i).ms_tcphd_ukf.ospa(1:MC,:),2)];
    Ysmc   = [Ysmc; mean(MC_results(i).ms_tcphd_smc.ospa(1:MC,:),2)];
    Zukf   = [Zukf; mean(MC_results(i).ms_member_ukf.ospa(1:MC,:),2)];
    Zsmc   = [Zsmc; mean(MC_results(i).ms_member_smc.ospa(1:MC,:),2)];
    ACTid =  [ACTid; i*ones(MC,1)];
end

my_labels = {'', '', '', '  p_D = 0.3', '', '', '', '', '', '', '  p_D = 0.5', '', '', '', '', '','', '', '  p_D = 0.9', '', ''};

xylabel = repmat('xyzqkj',nb_pD * MC,1); % we need nb_methods distinct labels
hfig = figure;
h_box = boxplot( [Xukf; Xsmc;  Yukf; Ysmc;  Zukf; Zsmc], {repmat(ACTid, nb_methods,1),  xylabel(:)},  'factorgap',[9], 'Widths', 0.9,  'FactorSeparator',[1]);
box on
set(gca,'xtick',1:24, 'xticklabel', my_labels) 
a = get(gca,'XTickLabel');
set(gca,'XTickLabel',a,'FontName','arial','fontsize', 25, 'fontweight', 'bold')

set(gca,'ygrid','on') 

color = { 'g', 'm', 'b', [0.5 0.1 0.2],'c', 'y',  'g',  'm', 'b', [0.5 0.1 0.2],'c', 'y', 'g',  'm', 'b', [0.5 0.1 0.2], 'c', 'y'};
h = findobj(gca,'Tag','Box');
for j=1:length(h)
   patch(get(h(j),'XData'),get(h(j),'YData'),color{j},'FaceAlpha',.5);
end

c = get(gca, 'Children');

legend(c(1:nb_methods), 'UKF MS-CPHD', 'SMC MS-CPHD',  'UKF MS-TCPHD', 'SMC MS-TCPHD', 'UKF MS-MeMBer', 'SMC MS-MeMBer' );
ylabel('Time-averaged OSPA error')

for i = 1:size(h_box,2) %  for each box in the box plot 
     set(h_box(1:4,i),'linewidth',2);  % 1:4 are the wiskers
    
     if mod(i,nb_methods) == 1
         set(h_box(5,i),'linewidth',2, 'color', color{nb_methods - mod(i,nb_methods) +1});  % 5 is the box
     elseif mod(i,nb_methods) == 2
         set(h_box(5,i),'linewidth',2, 'color', color{nb_methods - mod(i,nb_methods) +1});  % 5 is the box
     elseif mod(i,nb_methods) == 3
         set(h_box(5,i),'linewidth',2, 'color', color{nb_methods - mod(i,nb_methods) +1});  % 5 is the box
     elseif mod(i,nb_methods) == 4
         set(h_box(5,i),'linewidth',2, 'color', color{nb_methods - mod(i,nb_methods) +1});  % 5 is the box 
     elseif mod(i,nb_methods) == 5
         set(h_box(5,i),'linewidth',2, 'color', color{nb_methods - mod(i,nb_methods) +1});  % 5 is the box       
     else
         set(h_box(5,i),'linewidth',2, 'color', color{nb_methods - mod(i,nb_methods) +1});  % 5 is the box
     end
     
      set(h_box(6,i), 'linewidth', 5,  'color','k');  % 6 is the median, i.e. the notch
     
end
set(findall(hfig,'type','text'),'fontSize', 25,'fontWeight','bold')
set(gca,'LineWidth',2,'FontSize',36);
set(gcf,'color','w');

title_str =['Time-averaged OSPA $\lambda_c$ = ', num2str(MC_results(1).model.obs.lambda_c), ' and various $p_D$:'];  
title(title_str,  'Interpreter', 'LaTeX ', 'fontsize',40, 'fontName', 'Helvetica','fontWeight', 'Bold')

ylabel('Average OSPA error', 'Interpreter', 'LaTeX ', 'fontsize', 40, 'fontName', 'Helvetica','fontWeight', 'Bold')



end % function end
