function [ fHand ] = plot_cardinality_bearing_doppler( MC_results, truth )
%[ fHand ] = plot_cardinality_bearing_doppler( MC_results, truth )
%   Function that plots the mean and std of the cardinality estimates of 
%   the SMC and UKF implementations of the IC-CBMeMBer, MS-CPHD, MS-TCPHD and MS-MeMBer filters. 

y_max = 11;   % number of maximum targets (used to set the yaxis for cardinality plots)

model = MC_results.model;
x_time = 1:truth.K;
true_num_tg = truth.N;

fHand = figure;
subplot(8,1,1)  % UKF SCBMeMBer
    scb_mean_card = mean(MC_results.ic_cbmember_ukf.card(:,1:end));
    scb_std_card = std(MC_results.ic_cbmember_ukf.card(:,1:end));
    plot(x_time, true_num_tg, '-k','LineWidth',3, 'MarkerSize', 14)
    hold on
    plot(x_time, scb_mean_card, '+r','LineWidth',2, 'MarkerSize', 7)
    hold on
    plot(x_time, scb_mean_card + 3*scb_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    plot(x_time, scb_mean_card - 3*scb_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    %ylabel('Estimated Cardinality')
    %xlabel('Time sample [s]')
    set(gca,'XTickLabel','')
    title_str = ['UKF IC-CBMeMBer filter'];
    title(title_str,  'Interpreter', 'TeX ', 'fontsize',20, 'fontName', 'Helvetica')    
   % legend('True nb. of targets','Mean cardinality', 'Mean \pm 3 * std of cardinality')     
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');
    set(gca,'XTickLabel','')
    grid on
    box on
    ylim([0 y_max])
    set(gca,'GridLineStyle','--')
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot
subplot(8,1,2)  % SMC SCBMeMBer
    scb_mean_card = mean(MC_results.ic_cbmember_smc.card(:,1:end));
    scb_std_card = std(MC_results.ic_cbmember_smc.card(:,1:end));
    plot(x_time, true_num_tg, '-k','LineWidth',3, 'MarkerSize', 14)
    hold on
    plot(x_time, scb_mean_card, '+r','LineWidth',2, 'MarkerSize', 7)
    hold on
    plot(x_time, scb_mean_card + 3*scb_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    plot(x_time, scb_mean_card - 3*scb_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    %ylabel('Estimated Cardinality')
    %xlabel('Time sample [s]')
    set(gca,'XTickLabel','')
    title_str = ['SMC IC-CBMeMBer filter'];
    title(title_str,  'Interpreter', 'TeX ', 'fontsize',20, 'fontName', 'Helvetica')   
   % legend('True nb. of targets','Mean cardinality', 'Mean \pm 3 * std of cardinality')     
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');
    set(gca,'XTickLabel','')
    grid on
    box on
    ylim([0 y_max])
    set(gca,'GridLineStyle','--')
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot    
subplot(8,1,3)  % UKF CPHD
    cphd_ukf_mean_card = mean(MC_results.ms_cphd_ukf.card(:,1:end));
    cphd_ukf_std_card = std(MC_results.ms_cphd_ukf.card(:,1:end));
    plot(x_time, true_num_tg, '-k','LineWidth',3, 'MarkerSize', 14)
    hold on
    plot(x_time, cphd_ukf_mean_card, '+r','LineWidth',2, 'MarkerSize', 7)
    hold on
    plot(x_time, cphd_ukf_mean_card + 3*cphd_ukf_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    plot(x_time, cphd_ukf_mean_card - 3*cphd_ukf_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    %ylabel('Estimated Cardinality')
    %xlabel('Time sample [s]')
    set(gca,'XTickLabel','')
    title_str = ['UKF MS-CPHD filter'];
    title(title_str,  'Interpreter', 'TeX ', 'fontsize',20, 'fontName', 'Helvetica')   
   % legend('True nb. of targets','Mean cardinality', 'Mean \pm 3 * std of cardinality')     
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');
    set(gca,'XTickLabel','')
    grid on
    box on
    ylim([0 y_max])
    set(gca,'GridLineStyle','--')
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot    
subplot(8,1,4)  % SMC CPHD
    cphd_smc_mean_card = mean(MC_results.ms_cphd_smc.card(:,1:end));
    cphd_smc_std_card = std(MC_results.ms_cphd_smc.card(:,1:end));
    plot(x_time, true_num_tg, '-k','LineWidth',3, 'MarkerSize', 14)
    hold on
    plot(x_time, cphd_smc_mean_card, '+r','LineWidth',2, 'MarkerSize', 7)
    hold on
    plot(x_time, cphd_smc_mean_card + 3*cphd_smc_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    plot(x_time, cphd_smc_mean_card - 3*cphd_smc_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    %ylabel('Estimated Cardinality')
    %xlabel('Time sample [s]')
    set(gca,'XTickLabel','')
    title_str = ['SMC MS-CPHD filter'];
    title(title_str,  'Interpreter', 'TeX ', 'fontsize',20, 'fontName', 'Helvetica')   
    %legend('True nb. of targets','Mean cardinality', 'Mean \pm 3 * std of cardinality')     
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');
    set(gca,'XTickLabel','')
    grid on
    box on
    ylim([0 y_max])
    set(gca,'GridLineStyle','--')
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot
subplot(8,1,5)  % UKF TCPHD
    tcphd_ukf_mean_card = mean(MC_results.ms_tcphd_ukf.card(:,1:end));
    tcphd_ukf_std_card = std(MC_results.ms_tcphd_ukf.card(:,1:end));
    plot(x_time, true_num_tg, '-k','LineWidth',3, 'MarkerSize', 14)
    hold on
    plot(x_time, tcphd_ukf_mean_card, '+r','LineWidth',2, 'MarkerSize', 7)
    hold on
    plot(x_time, tcphd_ukf_mean_card + 3*tcphd_ukf_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    plot(x_time, tcphd_ukf_mean_card - 3*tcphd_ukf_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    %ylabel('Estimated Cardinality')
    %xlabel('Time sample [s]')
    set(gca,'XTickLabel','')
    title_str = ['UKF MS-TCPHD filter'];
    title(title_str,  'Interpreter', 'TeX ', 'fontsize',20, 'fontName', 'Helvetica')   
    %legend('True nb. of targets','Mean cardinality', 'Mean \pm 3 * std of cardinality')     
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');
    set(gca,'XTickLabel','')
    grid on
    box on
    ylim([0 y_max])
    set(gca,'GridLineStyle','--')
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot
    
subplot(8,1,6) % SMC TCPHD
    tcphd_smc_mean_card = mean(MC_results.ms_tcphd_smc.card(:,1:end));
    tcphd_smc_std_card = std(MC_results.ms_tcphd_smc.card(:,1:end));
    plot(x_time, true_num_tg, '-k','LineWidth',3, 'MarkerSize', 14)
    hold on    
    plot(x_time, tcphd_smc_mean_card, '+r','LineWidth',2, 'MarkerSize', 7)
    hold on
    plot(x_time, tcphd_smc_mean_card + 3*tcphd_smc_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    plot(x_time, tcphd_smc_mean_card - 3*tcphd_smc_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    ylabel('Estimated Cardinality')
    %xlabel('Time sample [s]')
    set(gca,'XTickLabel','')
    title_str = ['SMC MS-TCPHD filter'];
    title(title_str,  'Interpreter', 'TeX ', 'fontsize',20, 'fontName', 'Helvetica')   
    %legend('True nb. of targets','Mean cardinality', 'Mean \pm 3 * std of cardinality')     
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');
    set(gca,'XTickLabel','')
    grid on
    box on
    ylim([0 y_max])    
    set(gca,'GridLineStyle','--')
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot
subplot(8,1,7) % UKF MeMBer
    member_ukf_mean_card = mean(MC_results.ms_member_ukf.card(:,1:end));
    member_ukf_std_card = std(MC_results.ms_member_ukf.card(:,1:end));
    plot(x_time, true_num_tg, '-k','LineWidth',3, 'MarkerSize', 14)
    hold on    
    plot(x_time, member_ukf_mean_card, '+r','LineWidth',2, 'MarkerSize', 7)
    hold on
    plot(x_time, member_ukf_mean_card + 3*member_ukf_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    plot(x_time, member_ukf_mean_card - 3*member_ukf_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    %ylabel('Estimated Cardinality')
    %xlabel('Time sample [s]')
    set(gca,'XTickLabel','')
    title_str = ['UKF MS-MeMBer filter'];
    title(title_str,  'Interpreter', 'TeX ', 'fontsize',20, 'fontName', 'Helvetica')   
    %legend('True nb. of targets','Mean cardinality', 'Mean \pm 3 * std of cardinality')     
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');
    set(gca,'XTickLabel','')
    grid on
    box on
    ylim([0 y_max])    
    set(gca,'GridLineStyle','--')
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot 
    
subplot(8,1,8) % SMC MeMBer
    member_smc_mean_card = mean(MC_results.ms_member_smc.card(:,1:end));
    member_smc_std_card = std(MC_results.ms_member_smc.card(:,1:end));
    plot(x_time, true_num_tg, '-k','LineWidth',3, 'MarkerSize', 14)
    hold on    
    plot(x_time, member_smc_mean_card, '+r','LineWidth',2, 'MarkerSize', 7)
    hold on
    plot(x_time, member_smc_mean_card + 3*member_smc_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    plot(x_time, member_smc_mean_card - 3*member_smc_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    %ylabel('Estimated Cardinality')
    xlabel('Time sample [s]')
    %set(gca,'XTickLabel','')
    title_str = ['SMC MS-MeMBer filter'];
    title(title_str,  'Interpreter', 'TeX ', 'fontsize',20, 'fontName', 'Helvetica')   

    legend('True nb. of targets','Mean cardinality', 'Mean \pm 3 * std of cardinality')     
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');
    %set(gca,'XTickLabel','')
    grid on
    box on
    ylim([0 y_max])    
    set(gca,'GridLineStyle','--')
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot    
set(findall(fHand,'type','text'),'fontSize',25,'fontWeight','bold')
set(gcf,'color','w');


end

