function [ fHand ] = plot_cardinality_hist_bearing_doppler( MC_results, truth )
%[ fHand ] = plot_cardinality_hist_bearing_doppler( MC_results, truth )
%   Function that plots the cardinality histogram of 
%   the SMC and UKF implementations of the IC-CBMeMBer, MS-CPHD, MS-TCPHD and MS-MeMBer filters. 

bin_c = 0:1:9;%0.5:1:9.5;
 
     hist_icb_ukf        = zeros(length(bin_c), truth.K);
     hist_ms_member_ukf  = zeros(length(bin_c), truth.K);
     hist_ms_cphd_ukf    = zeros(length(bin_c), truth.K);
     hist_ms_tcphd_ukf   = zeros(length(bin_c), truth.K);

    hist_icb_smc        = zeros(length(bin_c), truth.K);
     hist_ms_member_smc  = zeros(length(bin_c), truth.K);
     hist_ms_cphd_smc    = zeros(length(bin_c), truth.K);
     hist_ms_tcphd_smc   = zeros(length(bin_c), truth.K);
      
     
 % Compute histograms    
for time_step = 1:truth.K

    hist_icb_ukf(:,time_step) = hist(MC_results.ic_cbmember_ukf.card(:,time_step), bin_c);
    hist_ms_member_ukf(:,time_step) = hist(MC_results.ms_member_ukf.card(:,time_step), bin_c);
    hist_ms_cphd_ukf(:,time_step) = hist(MC_results.ms_cphd_ukf.card(:,time_step), bin_c);
    hist_ms_tcphd_ukf(:,time_step) = hist(MC_results.ms_tcphd_ukf.card(:,time_step), bin_c);
    
    hist_icb_smc(:,time_step) = hist(MC_results.ic_cbmember_smc.card(:,time_step), bin_c);
    hist_ms_member_smc(:,time_step) = hist(MC_results.ms_member_smc.card(:,time_step), bin_c);
    hist_ms_cphd_smc(:,time_step) = hist(MC_results.ms_cphd_smc.card(:,time_step), bin_c);
    hist_ms_tcphd_smc(:,time_step) = hist(MC_results.ms_tcphd_smc.card(:,time_step), bin_c);    
    
end

% Normalize histograms
hist_icb_ukf       =  hist_icb_ukf ./  repmat(sum(hist_icb_ukf),length(bin_c), 1);
hist_ms_member_ukf = hist_ms_member_ukf ./  repmat(sum(hist_ms_member_ukf),length(bin_c), 1);
hist_ms_cphd_ukf   = hist_ms_cphd_ukf ./  repmat(sum(hist_ms_cphd_ukf),length(bin_c), 1);
hist_ms_tcphd_ukf  = hist_ms_tcphd_ukf ./  repmat(sum(hist_ms_tcphd_ukf),length(bin_c), 1);

% Normalize histograms
hist_icb_smc       =  hist_icb_smc ./  repmat(sum(hist_icb_smc),length(bin_c), 1);
hist_ms_member_smc = hist_ms_member_smc ./  repmat(sum(hist_ms_member_smc),length(bin_c), 1);
hist_ms_cphd_smc   = hist_ms_cphd_smc ./  repmat(sum(hist_ms_cphd_smc),length(bin_c), 1);
hist_ms_tcphd_smc  = hist_ms_tcphd_smc ./  repmat(sum(hist_ms_tcphd_smc),length(bin_c), 1);


fHand = figure;
    subplot(8,1,1)  % UKF SCBMeMBer
    imagesc(1:truth.K, bin_c, hist_icb_ukf)
    hold on
    set(gca,'Ydir','Normal')
    plot(1:truth.K,truth.N, 'k', 'lineWidth', 3)
    title('IC-CBMeMBer UKF filter')
    colorbar
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');
    
subplot(8,1,2)  % SMC SCBMeMBer
    imagesc(1:truth.K, bin_c, hist_icb_smc)
    hold on
    set(gca,'Ydir','Normal')
    plot(1:truth.K,truth.N, 'k', 'lineWidth', 3)
    title('IC-CBMeMBer SMC filter')
    colorbar
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');
    
subplot(8,1,3)  % UKF CPHD
    imagesc(1:truth.K, bin_c, hist_ms_cphd_ukf)
    hold on
    set(gca,'Ydir','Normal')
    plot(1:truth.K,truth.N, 'k', 'lineWidth', 3)
    title('MS-CPHD UKF filter')
    colorbar
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot   
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');

subplot(8,1,4)  % SMC CPHD
    imagesc(1:truth.K, bin_c, hist_ms_cphd_smc)
    hold on
    set(gca,'Ydir','Normal')
    plot(1:truth.K,truth.N, 'k', 'lineWidth', 3)
    title('MS-CPHD SMC filter')
    colorbar
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot   
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');

subplot(8,1,5)  % UKF TCPHD
    imagesc(1:truth.K, bin_c, hist_ms_tcphd_ukf)
    hold on
    set(gca,'Ydir','Normal')
    plot(1:truth.K,truth.N, 'k', 'lineWidth', 3)
    title('MS-TCPHD UKF filter')
    colorbar
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot   
    ylabel('Cardinality')

subplot(8,1,6) % SMC TCPHD
    imagesc(1:truth.K, bin_c, hist_ms_tcphd_smc)
    hold on
    set(gca,'Ydir','Normal')
    plot(1:truth.K,truth.N, 'k', 'lineWidth', 3)
    title('MS-TCPHD SMC filter')
    colorbar
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot   
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');

subplot(8,1,7) % UKF MeMBer
    imagesc(1:truth.K, bin_c, hist_ms_member_ukf)
    hold on
    set(gca,'Ydir','Normal')
    plot(1:truth.K,truth.N, 'k', 'lineWidth', 3)
    title('MS-MeMBer UKF filter')
    colorbar
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot   
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');
    
subplot(8,1,8) % SMC MeMBer
    imagesc(1:truth.K, bin_c, hist_ms_member_smc)
    hold on
    set(gca,'Ydir','Normal')
    plot(1:truth.K,truth.N, 'k', 'lineWidth', 3)
    title('MS-MeMBer SMC filter')
    colorbar
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot   
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');

    xlabel('Time [s]')
set(findall(fHand,'type','text'),'fontSize',25,'fontWeight','bold')
set(gcf,'color','w');


end

