function [ fHand ] = plot_cardinality_hist_linGauss( MC_results, truth )
%[ fHand ] = plot_cardinality_hist_linGauss( MC_results, truth )
%   Function that plots the cardinality histogram of 
%   the SMC and UKF implementations of the IC-CBMeMBer, MS-CPHD, MS-TCPHD and MS-MeMBer filters. 

bin_c = 0:1:9;%0.5:1:9.5;
 
     hist_icb        = zeros(length(bin_c), truth.K);
     hist_ms_member  = zeros(length(bin_c), truth.K);
     hist_ms_cphd    = zeros(length(bin_c), truth.K);
     hist_ms_tcphd   = zeros(length(bin_c), truth.K);
   
% Compute histograms     
for time_step = 1:truth.K
    hist_icb(:,time_step) = hist(MC_results.ic_cbmember.card(:,time_step), bin_c);
    hist_ms_member(:,time_step) = hist(MC_results.ms_member.card(:,time_step), bin_c);
    hist_ms_cphd(:,time_step) = hist(MC_results.ms_cphd.card(:,time_step), bin_c);
    hist_ms_tcphd(:,time_step) = hist(MC_results.ms_tcphd.card(:,time_step), bin_c);   
end

% Normalize histograms
hist_icb       = hist_icb ./  repmat(sum(hist_icb),length(bin_c), 1);
hist_ms_member = hist_ms_member ./  repmat(sum(hist_ms_member),length(bin_c), 1);
hist_ms_cphd   = hist_ms_cphd ./  repmat(sum(hist_ms_cphd),length(bin_c), 1);
hist_ms_tcphd  = hist_ms_tcphd ./  repmat(sum(hist_ms_tcphd),length(bin_c), 1);


fHand = figure;
    subplot(4,1,1)  % IC-CBMeMBer
    imagesc(1:truth.K, bin_c, hist_icb)
    hold on
    set(gca,'Ydir','Normal')
    plot(1:truth.K,truth.N, 'k', 'lineWidth', 3)
    title('IC-CBMeMBer filter')
    colorbar
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');
 
subplot(4,1,2)  % MS CPHD
    imagesc(1:truth.K, bin_c, hist_ms_cphd)
    hold on
    set(gca,'Ydir','Normal')
    plot(1:truth.K,truth.N, 'k', 'lineWidth', 3)
    title('MS-CPHD filter')
    colorbar
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot   
    ylabel('Cardinality')
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');
    
subplot(4,1,3)  % MS TCPHD
    imagesc(1:truth.K, bin_c, hist_ms_tcphd)
    hold on
    set(gca,'Ydir','Normal')
    plot(1:truth.K,truth.N, 'k', 'lineWidth', 3)
    title('MS-TCPHD filter')
    colorbar
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot   
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');

    subplot(4,1,4) % MS MeMBer
    imagesc(1:truth.K, bin_c, hist_ms_member)
    hold on
    set(gca,'Ydir','Normal')
    plot(1:truth.K,truth.N, 'k', 'lineWidth', 3)
    title('MS-MeMBer filter')
    colorbar
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot   
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');

    xlabel('Time [s]')
set(findall(fHand,'type','text'),'fontSize',25,'fontWeight','bold')
set(gcf,'color','w');


end

