function [ fHand ] = plot_cardinality_linGauss( MC_results, truth )
%[ fHand ] = plot_cardinality_linGauss( MC_results, truth )
%   Function that plots the mean and std of the cardinality estimates of 
%   the IC-CBMeMBer, MS-CPHD, MS-TCPHD and MS-MeMBer filters. 

y_max = 9;   % number of maximum targets (used to set the yaxis for cardinality plots)

x_time = 1:truth.K;
true_num_tg = truth.N;
model = MC_results.model;

fHand = figure;
subplot(4,1,1)  % IC CBMeMBer
    ic_cbmember_mean_card = mean(MC_results.ic_cbmember.card(:,1:end));
    ic_cbmember_std_card = std(MC_results.ic_cbmember.card(:,1:end));
    plot(x_time, true_num_tg, '-k','LineWidth',3, 'MarkerSize', 14)
    hold on
    plot(x_time, ic_cbmember_mean_card, '+r','LineWidth',2, 'MarkerSize', 7)
    hold on
    plot(x_time, ic_cbmember_mean_card + 3*ic_cbmember_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    plot(x_time, ic_cbmember_mean_card - 3*ic_cbmember_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    %ylabel('Estimated Cardinality')
    %xlabel('Time sample [s]')
    set(gca,'XTickLabel','')
    title_str = ['IC-CBMeMBer cardinality {p_D} = ', num2str(model.obs.pD(1)) , ' and s=', num2str(model.obs.nb_sensors)];
    title(title_str,  'Interpreter', 'TeX ', 'fontsize',20, 'fontName', 'Helvetica')
   % legend('True nb. of targets','Mean cardinality', 'Mean \pm 3 * std of cardinality')     
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');
    grid on
    box on
    ylim([0 y_max+1])
    set(gca,'GridLineStyle','--')
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot

subplot(4,1,2)  %  CPHD
    cphd_mean_card = mean(MC_results.ms_cphd.card(:,1:end));
    cphd_std_card = std(MC_results.ms_cphd.card(:,1:end));
    plot(x_time, true_num_tg, '-k','LineWidth',3, 'MarkerSize', 14)
    hold on
    plot(x_time, cphd_mean_card, '+r','LineWidth',2, 'MarkerSize', 7)
    hold on
    plot(x_time, cphd_mean_card + 3*cphd_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    plot(x_time, cphd_mean_card - 3*cphd_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    %ylabel('Estimated Cardinality')
    %xlabel('Time sample [s]')
    title_str = ['MS-CPHD cardinality {p_D} = ', num2str(model.obs.pD(1)) , ' and s=', num2str(model.obs.nb_sensors)];
    title(title_str,  'Interpreter', 'TeX ', 'fontsize',20, 'fontName', 'Helvetica')
    %legend('True nb. of targets','Mean cardinality', 'Mean \pm 3 * std of cardinality')     
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');
    set(gca,'XTickLabel','')
    grid on
    box on
    ylim([0 y_max])
    set(gca,'GridLineStyle','--')
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot
    
    
subplot(4,1,3)  %  TCPHD
    tcphd_mean_card = mean(MC_results.ms_tcphd.card(:,1:end));
    tcphd_std_card = std(MC_results.ms_tcphd.card(:,1:end));
    plot(x_time, true_num_tg, '-k','LineWidth',3, 'MarkerSize', 14)
    hold on
    plot(x_time, tcphd_mean_card, '+r','LineWidth',2, 'MarkerSize', 7)
    hold on
    plot(x_time, tcphd_mean_card + 3*tcphd_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    plot(x_time, tcphd_mean_card - 3*tcphd_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    ylabel('Estimated Cardinality')
    %xlabel('Time sample [s]')
    title_str = ['MS-TCPHD cardinality {p_D} = ', num2str(model.obs.pD(1)) , ' and s=', num2str(model.obs.nb_sensors)];
    title(title_str,  'Interpreter', 'TeX ', 'fontsize',20, 'fontName', 'Helvetica')
    %legend('True nb. of targets','Mean cardinality', 'Mean \pm 3 * std of cardinality')     
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');
    set(gca,'XTickLabel','')
    grid on
    box on
    ylim([0 y_max])
    set(gca,'GridLineStyle','--')
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot
    

subplot(4,1,4) % MS MeMBer
    member_mean_card = mean(MC_results.ms_member.card(:,1:end));
    member_std_card = std(MC_results.ms_member.card(:,1:end));
    plot(x_time, true_num_tg, '-k','LineWidth',3, 'MarkerSize', 14)
    hold on    
    plot(x_time, member_mean_card, '+r','LineWidth',2, 'MarkerSize', 7)
    hold on
    plot(x_time, member_mean_card + 3*member_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    plot(x_time, member_mean_card - 3*member_std_card, '--b','LineWidth',2, 'MarkerSize', 14)
    %ylabel('Estimated Cardinality')
    xlabel('Time sample [s]')
    %set(gca,'XTickLabel','')
    title_str = ['MS-MeMBer cardinality {p_D} = ', num2str(model.obs.pD(1)) , ' and s=', num2str(model.obs.nb_sensors)];
    title(title_str,  'Interpreter', 'TeX ', 'fontsize',20, 'fontName', 'Helvetica')
    legend('True nb. of targets','Mean cardinality', 'Mean \pm 3 * std of cardinality')     
    set(gca,'LineWidth',2,'FontSize',20,'fontWeight','bold');
    grid on
    box on
    ylim([0 y_max])    
    set(gca,'GridLineStyle','--')
    set(gca(), 'LooseInset', get(gca(), 'TightInset') + [0 0 0.001 0]);  % eliminate margins in a plot 
   
set(findall(fHand,'type','text'),'fontSize',25,'fontWeight','bold')
set(gcf,'color','w');


end

