function fHand = plot_tracks(model, truth)
% fHand = plot_tracks(model, truth)
% INPUT:
%      model - struc that contains kinematic and obs. model params. 
%      truth - struc that cointains groungtruth tracks
% OUTPUT:
%      fHand - figure handle
%
% Contact: augustin.saucan@mail.mcgill.ca

fHand = figure;
subplot(2,1,1) 

%% First plot the birth densities 
for j=1:model.birth.J_gamma
    plot(model.birth.m_gamma(1,j), model.birth.m_gamma(2,j),'.r', 'MarkerSize', 7);
    hold on
    hbirth = error_ellipse(model.birth.P_gamma(1:2,1:2), model.birth.m_gamma(1:2,j), 'conf', 0.9, 'style', 'r' );
end
    hold on
    if isfield(model.obs, 'sensor_pos')
        hsensors = plot(model.obs.sensor_pos(1,:), model.obs.sensor_pos(2,:),'og','LineWidth',4, 'MarkerSize', 14);   % plot sensor positions
    else
        hsensors = [];
    end
for k =  1:truth.K
        if ~isempty(truth.X{k})
            htaracks = plot(truth.X{k}(1,:), truth.X{k}(2,:), '.k','LineWidth',3, 'MarkerSize', 14);              % plot target tracks
        end
        hold on
end
    axis([model.obs.xrange model.obs.yrange])
    ylabel('Y coordinate [m]')
    xlabel('X coordinate [m]')
    grid on; box on; set(gca,'GridLineStyle','--');
    title('True target tracks')
    if ~isempty(hsensors)
        legend([hbirth hsensors htaracks], {'Birth pdf conf. 90%','Sensor positions', 'Target tracks'})
    else
        legend([hbirth htaracks], {'Birth pdf conf. 90%', 'Target tracks'})
    end
    set(gca,'FontSize',25,'fontWeight','bold');
    %axis equal
subplot(2,1,2)   
    plot(1:truth.K, truth.N,'-k','LineWidth',3, 'MarkerSize', 8)
    axis([0 truth.K 1 9])
    ylabel('True cardinality')
    xlabel('Time sample [s]')
    grid on; box on; set(gca,'GridLineStyle','--');
    set(gca,'FontSize',25,'fontWeight','bold');
set(findall(fHand,'type','text'),'fontSize',25,'fontWeight','bold')


end

