% This is a demo script for a single run of MS-CPHD, MS-TCPHD and MS-MeMBer
% filters in UKF and SMC implementations.
%
% Contact: augustin.saucan@mail.mcgill.ca

close all
clear all
clc

%restoredefaultpath       % clear previous path
addpath(genpath(pwd));   % append all folders to current path

fc = 300;       % carrier frequency
 
sensor_pos = [  0      0   0 -350 350 ;  % sensor positions X coord
                350  -350  0  0   0 ];  % sensor positions Y coord
 
pD = 0.3 * ones(1,size(sensor_pos,2));  % probabilities of detection of sensors  
clutter_rate = 5;                       % clutter rate (identical for all sensors)

%% Generate model parameters 
model = gen_model_bearing_doppler(fc, pD, sensor_pos, clutter_rate);
%% Generate filtering parameters
filter_params = gen_filters();
%% Generate ground truth tracks
truth = gen_truth(model, 'noise', 1, 50 ); 
%% Plot True tracks
handles = plot_tracks(model,truth);
set(gcf,'color','w');
%% Run filters

% seed for measurement generation
meas_seed = 200;                

%%% SMC IC-CBMeMBer
meas  =  gen_meas_bearing_doppler(model,truth, meas_seed);
est_scb_member_smc = filter_ic_cbmember_smc(filter_params.ic_cbmember_smc, model, meas, truth);                         % run filter
fprintf('\n IC-CBMeMBer SMC Time-average OSPA %d',mean(est_scb_member_smc.ospa));
fprintf('\n IC-CBMeMBer SMC Run Time %d sec \n', est_scb_member_smc.all_time);
handles = plot_results(model, truth, est_scb_member_smc, 0);  

%%% UKF IC-CBMeMBer
meas  =  gen_meas_bearing_doppler(model,truth, meas_seed);
est_scb_member_ukf = filter_ic_cbmember_ukf(filter_params.ic_cbmember_ukf, model, meas, truth);                         % run filter
fprintf('\n IC-CBMeMBer UKF Time-average OSPA %d',mean(est_scb_member_ukf.ospa));
fprintf('\n IC-CBMeMBer UKF Run Time %d sec \n', est_scb_member_ukf.all_time);
handles = plot_results(model, truth, est_scb_member_ukf, 0); 

%%% MS multi-Bernoulli SMC 
meas  =  gen_meas_bearing_doppler(model,truth, meas_seed);
est_ms_member_smc = filter_ms_member_smc(filter_params.ms_member_smc, model, meas, truth);                               % run filter
fprintf('\n MS-MeMBer SMC Time-average OSPA %d',mean(est_ms_member_smc.ospa));
fprintf('\n MS-MeMBer SMC Run Time %d sec \n', est_ms_member_smc.all_time);
handles = plot_results(model,truth, est_ms_member_smc, 0);

%%% MS multi-Bernoulli UKF 
meas  =  gen_meas_bearing_doppler(model,truth, meas_seed);
est_ms_member_ukf = filter_ms_member_ukf(filter_params.ms_member_ukf, model, meas, truth);                               % run filter
fprintf('\n MS-MeMBer UKF Time-average OSPA %d',mean(est_ms_member_ukf.ospa));
fprintf('\n MS-MeMBer UKF Run Time MeMBer SMC %d sec \n', est_ms_member_ukf.all_time);
handles = plot_results(model,truth, est_ms_member_ukf, 0);  

%%% MS TCPHD SMC
meas  =  gen_meas_bearing_doppler(model,truth, meas_seed);
est_ms_tcphd_smc = filter_ms_tcphd_smc(filter_params.ms_tcphd_smc, model, meas, truth);                        % run filter
fprintf('\n MS-TCPHD SMC Time-average OSPA %d',mean(est_ms_tcphd_smc.ospa));
fprintf('\n MS-TCPHD SMC Run Time %d sec \n', est_ms_tcphd_smc.all_time);
handles = plot_results(model, truth, est_ms_tcphd_smc, 0);  


%%% MS TCPHD UKF
meas  =  gen_meas_bearing_doppler(model,truth, meas_seed);
est_ms_tcphd_ukf = filter_ms_tcphd_ukf(filter_params.ms_tcphd_ukf, model, meas, truth);                        % run filter
fprintf('\n MS-TCPHD UKF Time-average OSPA %d',mean(est_ms_tcphd_ukf.ospa));
fprintf('\n MS-TCPHD UKF Run Time %d sec \n', est_ms_tcphd_ukf.all_time);
handles = plot_results(model, truth, est_ms_tcphd_ukf,0);                          

%%% MS CPHD SMC
meas  =  gen_meas_bearing_doppler(model,truth, meas_seed);
est_ms_cphd_smc = filter_ms_cphd_smc(filter_params.ms_cphd_smc, model, meas, truth);                         % run filter
fprintf('\n MS-CPHD SMC Time-average OSPA %d',mean(est_ms_cphd_smc.ospa));
fprintf('\n MS-CPHD SMC Run Time %d sec \n', est_ms_cphd_smc.all_time);
handles = plot_results(model, truth, est_ms_cphd_smc, 0); 


%%% MS CPHD UKF
meas  =  gen_meas_bearing_doppler(model,truth, meas_seed);
est_ms_cphd_ukf = filter_ms_cphd_ukf(filter_params.ms_cphd_ukf, model, meas, truth);                         % run filter
fprintf('\n MS-CPHD UKF Time-average OSPA %d',mean(est_ms_cphd_ukf.ospa));
fprintf('\n MS-CPHD UKF Run Time %d sec \n', est_ms_cphd_ukf.all_time);
handles = plot_results(model, truth, est_ms_cphd_ukf, 0);                       

