% This is a demo script for a single run of MS-CPHD, MS-TCPHD and MS-MeMBer
% filters in UKF and SMC implementations.
%
% Contact: augustin.saucan@mail.mcgill.ca

close all
clear all
clc

%restoredefaultpath       % clear previous path
addpath(genpath(pwd));   % append all folders to current path

nb_sensors = 5;         % specify number of sensors
pD = 0.5 * ones(1,nb_sensors);   % sensor prob. of detection

%% Generate model parameters (kinematic and observation) 
model = gen_model_linGauss(pD);
%% Generate ground truth tracks
truth = gen_truth(model, 'noise', 1, 50 ); 
%% Generate filtering parameters
filter_params = gen_filters();
%% Generate Measurements
meas  =  gen_meas_linGauss(model,truth, 25);
% Plot True tracks
handles = plot_tracks(model,truth);
%% Run filters


%%% MS IC-CBMeMBer Kalman filter implementation
est_ms_ic_cbmember = filter_ic_cbmember_kf(filter_params.ic_cbmember_kf, model, meas, truth);                         % run filter
fprintf('\n MS-IC-MeMBer Time-average OSPA %d',mean(est_ms_ic_cbmember.ospa));
fprintf('\n MS-IC-MeMBer Run Time %d sec \n', est_ms_ic_cbmember.all_time);
handles = plot_results(model, truth, est_ms_ic_cbmember, 0); 


%%% MS multi-Bernoulli Kalman filter implementation
est_ms_member = filter_ms_member_kf(filter_params.ms_member_kf, model, meas, truth);                         % run filter
fprintf('\n MS-MeMBer Time-average OSPA %d',mean(est_ms_member.ospa));
fprintf('\n MS-MeMBer Run Time  %d sec \n', est_ms_member.all_time);
handles = plot_results(model, truth, est_ms_member, 0); 


 %%% MS CPHD Kalman filter implementation
est_ms_cphd = filter_ms_cphd_kf(filter_params.ms_cphd_kf, model, meas, truth);                         % run filter
fprintf('\n MS-CPHD Time-average OSPA %d',mean(est_ms_cphd.ospa));
fprintf('\n MS-CPHD Run Time %d sec \n', est_ms_cphd.all_time);
handles = plot_results(model, truth, est_ms_cphd, 0); 


%%% MS TCPHD Kalman filter implementation
est_ms_tcphd = filter_ms_tcphd_kf(filter_params.ms_tcphd_kf, model, meas, truth);                        % run filter
fprintf('\n MS-TCPHD Time-average OSPA %d',mean(est_ms_tcphd.ospa));
fprintf('\n MS-TCPHD Run Time %d sec \n', est_ms_tcphd.all_time);
handles = plot_results(model, truth, est_ms_tcphd, 0); 

