% This is a demo script that performs a MC analysis of the MS-MeMBer [1], 
% MS-CPHD [2], MS-TCPHD [1] and IC-CBMeMBer filters (based on the CBMeMBer 
% of [3]).
%
% [1] A. Saucan, M. Coates, and M. Rabbat,  "A multi-sensor multi-Bernoulli 
% filter"  2016, arXiv:1609.05108 [stat.ME]
%
% [2] S. Nannuru, S. Blouin, M. Coates, and M. Rabbat,  "Multisensor CPHD 
% filter", IEEE Trans. Aerosp. and Electron. Syst., vol. 52, no. 4, pp. 
% 1834-1854, Aug. 2016, arXiv:1504.06342v2 [stat.ME]
%
% [3] B.-T. Vo, B.-N. Vo, and A. Cantoni, “The cardinality balanced 
% multi-target multi-Bernoulli filter and its implementations,”
% IEEE Trans. Signal Process., vol. 57, no. 2, pp. 409 – 423, Feb. 2009.
%
% Contact: augustin.saucan@mail.mcgill.ca

clear all
close all
clc

%restoredefaultpath       % clear previous path
addpath(genpath(pwd));   % append all folders to current path

%% Generate filtering parameters
filter_params = gen_filters();

%% specify prob. of detection and number of sensors for which an MC simulation will be performed
pD_params = [0.5 0.7 0.9];
nb_sensors_params = [3:2:11];
MC = 100;                        % number of MC runs
       
start_time = tic;   

[ MC_output, truth ] = run_MC_lin_Gauss(filter_params, nb_sensors_params, pD_params, MC);

total_time = toc(start_time);

fprintf('\n ##### I reached the end and it took %d seconds (%d hours)! #######\n', total_time, total_time/3600)

%%  Table 
nb_sensors_index = 1;   % 1 for   3;  2 for   5; 3 for   7; 4 for 9; 5 for 11; 
pd_index = 1;           % 1 for 0.5 ; 2 for 0.7; 3 for 0.9; 

ic_cbmember_avr = mean(MC_output(nb_sensors_index, pd_index).ic_cbmember.ospa, 2);

member_avr      = mean(MC_output(nb_sensors_index, pd_index).ms_member.ospa, 2);

cphd_avr        = mean(MC_output(nb_sensors_index, pd_index).ms_cphd.ospa, 2);

tcphd_avr       = mean(MC_output(nb_sensors_index, pd_index).ms_tcphd.ospa, 2);

fprintf('\n IC_CBMeMBer:')
strcat(num2str(median(ic_cbmember_avr)), ' [', num2str(quantile(ic_cbmember_avr,[0.25 0.75])),']', num2str(mean(MC_output(nb_sensors_index, pd_index).ic_cbmember.all_time)/truth.K), 'sec')

fprintf('\n MS_MeMBer:')
strcat(num2str(median(member_avr)), ' [', num2str(quantile(member_avr,[0.25 0.75])),']', num2str(mean(MC_output(nb_sensors_index, pd_index).ms_member.all_time)/truth.K), 'sec')

fprintf('\n MS_CPHD:')
strcat(num2str(median(cphd_avr)), ' [', num2str(quantile(cphd_avr,[0.25 0.75])),']', num2str(mean(MC_output(nb_sensors_index, pd_index).ms_cphd.all_time)/truth.K), 'sec')

fprintf('\n MS_TCPHD:')
strcat(num2str(median(tcphd_avr)), ' [', num2str(quantile(tcphd_avr,[0.25 0.75])),']', num2str(mean(MC_output(nb_sensors_index, pd_index).ms_tcphd.all_time)/truth.K), 'sec')

% Recompute OSPA if necessary 
%[ MC_output2 ] = compute_ospa_linGauss( MC_output, truth, MC );

%% Calls to plotting functions

hFig_card = plot_cardinality_linGauss( MC_output(1,1), truth );

hFig_card_hist = plot_cardinality_hist_linGauss( MC_output(1,1), truth );

hFig_ospa = box_plot_time_averaged_OSPA_linGauss( MC_output(:,1), nb_sensors_params, MC );

hFig_ospa = box_plot_time_averaged_OSPA_linGauss_3methods( MC_output(:,2), nb_sensors_params, MC );


hFig_time = box_plot_run_time_linGauss( MC_output(:,1), truth, nb_sensors_params, MC );



